package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.QuoteMaterialTypeMapper;
import com.ruoyi.system.domain.QuoteMaterialType;
import com.ruoyi.system.service.IQuoteMaterialTypeService;

/**
 * 项目报价--物料分类Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class QuoteMaterialTypeServiceImpl implements IQuoteMaterialTypeService 
{
    @Autowired
    private QuoteMaterialTypeMapper quoteMaterialTypeMapper;

    /**
     * 查询项目报价--物料分类
     * 
     * @param id 项目报价--物料分类主键
     * @return 项目报价--物料分类
     */
    @Override
    public QuoteMaterialType selectQuoteMaterialTypeById(Long id)
    {
        return quoteMaterialTypeMapper.selectQuoteMaterialTypeById(id);
    }


    public String selecttypesByIds(List<String> ids) {
        return quoteMaterialTypeMapper.selecttypesByIds(ids);
    }
    /**
     * 查询项目报价--物料分类列表
     * 
     * @param quoteMaterialType 项目报价--物料分类
     * @return 项目报价--物料分类
     */
    @Override
    public List<QuoteMaterialType> selectQuoteMaterialTypeList(QuoteMaterialType quoteMaterialType)
    {
        return quoteMaterialTypeMapper.selectQuoteMaterialTypeList(quoteMaterialType);
    }

    /**
     * 新增项目报价--物料分类
     * 
     * @param quoteMaterialType 项目报价--物料分类
     * @return 结果
     */
    @Override
    public int insertQuoteMaterialType(QuoteMaterialType quoteMaterialType)
    {
        return quoteMaterialTypeMapper.insertQuoteMaterialType(quoteMaterialType);
    }

    /**
     * 修改项目报价--物料分类
     * 
     * @param quoteMaterialType 项目报价--物料分类
     * @return 结果
     */
    @Override
    public int updateQuoteMaterialType(QuoteMaterialType quoteMaterialType)
    {
        return quoteMaterialTypeMapper.updateQuoteMaterialType(quoteMaterialType);
    }

    /**
     * 批量删除项目报价--物料分类
     * 
     * @param ids 需要删除的项目报价--物料分类主键
     * @return 结果
     */
    @Override
    public int deleteQuoteMaterialTypeByIds(Long[] ids)
    {
        return quoteMaterialTypeMapper.deleteQuoteMaterialTypeByIds(ids);
    }

    /**
     * 删除项目报价--物料分类信息
     * 
     * @param id 项目报价--物料分类主键
     * @return 结果
     */
    @Override
    public int deleteQuoteMaterialTypeById(Long id)
    {
        return quoteMaterialTypeMapper.deleteQuoteMaterialTypeById(id);
    }
}
